﻿namespace ExampleProject
{
    /// <summary>
    /// Demonstrates property getter/setter behavior and assignment within a method.
    /// </summary>
    public class MyClass
    {
        // Backing field for the property. Note it's only written to by the setter.
        private int myProperty;

        /// <summary>
        /// Gets a fixed value (5) and sets the backing field 'myProperty'.
        /// </summary>
        public int MyProperty
        {
            // The getter always returns the constant value 5.
            get => 5;

            // The setter assigns the provided value to the private backing field.
            set => myProperty = value;
        }

        /// <summary>
        /// Returns the current value of the private backing field 'myProperty'.
        /// Useful for observing the effect of the setter.
        /// </summary>
        /// <returns>The value stored in the myProperty field.</returns>
        public int GetBackingFieldValue()
        {
            return myProperty;
        }

        /// <summary>
        /// Assigns 4 to the MyProperty (invoking the setter) and returns the assigned value (4).
        /// </summary>
        /// <returns>The value 4, which is the result of the assignment expression.</returns>
        public int GetMyProperty()
        {
            // This expression first calls the setter of MyProperty with the value 4,
            // setting the 'myProperty' field to 4.
            // The assignment expression itself evaluates to the assigned value (4).
            return MyProperty = 4;
        }
    }
}
